@@ -30,6 +30,7 @@ from firexkit.result import get_tasks_names_from_results, wait_for_any_results,
 from firexkit.resources import get_firex_css_filepath, get_firex_logo_filepath
 from firexkit.firexkit_common import JINJA_ENV
 import time
+from firexkit.permissions import DEFAULT_CHMOD_MODE
 
 logger = get_task_logger(__name__)
 
@@ -94,27 +95,29 @@ def create_collapse_ops(flex_collapse_ops_spec):
 def expand_self_op():
     return {'operation': 'expand', 'targets': ['self']}
 
+FLAME_COLLAPSE_KEY = '_default_display'
+
+def flame_collapse_formatter(ops, task):
+    filled_ops = []
+    for op in ops:
+        if 'targets' not in op or not isinstance(op['targets'], list):
+            # Ignore malformed operations.
+            continue
+        filled_op = {
+            # defaults.
+            'relative_to_nodes': {'type': 'task_uuid', 'value': task.request.id},
+            'source_node': {'type': 'task_uuid', 'value': task.request.id},
+            'operation': 'collapse',
+        }
+        filled_op.update(op)
+        filled_ops.append(filled_op)
+    return filled_ops
+
 
 def flame_collapse(flex_collapse_ops):
-    def formatter(ops, task):
-        filled_ops = []
-        for op in ops:
-            if 'targets' not in op or not isinstance(op['targets'], list):
-                # Ignore malformed operations.
-                continue
-            filled_op = {
-                # defaults.
-                'relative_to_nodes': {'type': 'task_uuid', 'value': task.request.id},
-                'source_node': {'type': 'task_uuid', 'value': task.request.id},
-                'operation': 'collapse',
-            }
-            filled_op.update(op)
-            filled_ops.append(filled_op)
-        return filled_ops
-
     static_ops = create_collapse_ops(flex_collapse_ops)
-    return flame('_default_display', formatter, data_type='object', bind=True, on_next=True, on_next_args=[static_ops],
-                 decorator_name=flame_collapse.__name__)
+    return flame(FLAME_COLLAPSE_KEY, flame_collapse_formatter, data_type='object', bind=True, on_next=True,
+                 on_next_args=[static_ops], decorator_name=flame_collapse.__name__)
 
 
 def _default_flame_formatter(data):
@@ -864,7 +867,7 @@ class FireXTask(Task):
         else:
             _task_logging_dirpath = self.get_task_logging_dirpath(self.file_logging_dirpath, self.request.hostname)
             if not os.path.exists(_task_logging_dirpath):
-                os.makedirs(_task_logging_dirpath, mode=0o777, exist_ok=True)
+                os.makedirs(_task_logging_dirpath, mode=DEFAULT_CHMOD_MODE, exist_ok=True)
             self._task_logging_dirpath = _task_logging_dirpath
             return self._task_logging_dirpath
 
@@ -990,13 +993,13 @@ class FireXTask(Task):
                 # 'on_next' during flame_data_config registration.
                 if flame_key in data \
                         or flame_config['on_next'] \
-                        or flame_key is None:
+                        or (flame_key is None or flame_key == '*'):
                     formatter_kwargs = {'task': self} if flame_config['bind'] else {}
                     if flame_key in data:
                         formatter_args = [data[flame_key]]
                     elif flame_config['on_next']:
                         formatter_args = flame_config['on_next_args']
-                    elif flame_key is None:
+                    elif flame_key is None or flame_key == '*':
                         # None means execute formatter with all data.
                         formatter_args = [data]
                     else:
@@ -1030,6 +1033,23 @@ class FireXTask(Task):
                           for flame_key, html_data in kwargs.items()}
         self.send_firex_event_raw({'flame_data': formatted_data})
 
+    def send_display_collapse(self, task_uuid: str = None):
+        """
+            Collapse the current task (default), or collapse the task with the supplied UUID.
+        """
+        if task_uuid is None:
+            task_uuid = self.request.id
+        formatted_data = {
+            FLAME_COLLAPSE_KEY: {
+                'value': flame_collapse_formatter([{
+                    'targets': ['self'],
+                    'relative_to_nodes': {'type': 'task_uuid', 'value': task_uuid},
+                }], self),
+                'type': 'object',
+                'order': time.time()}
+        }
+        self.send_firex_event_raw({'flame_data': formatted_data})
+
 
 def undecorate_func(func):
     undecorated_func = func
